@@ -1,23 +1,10 @@
 /*
   This file is part of KDE Kontact.
 
-  Copyright (C) 2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2008 Rafael Fernández López <ereslibre@kde.org>
+  SPDX-FileCopyrightText: 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2008 Rafael Fernández López <ereslibre@kde.org>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; see the file COPYING.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "iconsidepane.h"
@@ -178,9 +165,9 @@ public:
 protected:
     bool lessThan(const QModelIndex &left, const QModelIndex &right) const override
     {
-        KontactInterface::Plugin *leftPlugin
+        auto *leftPlugin
             = static_cast<KontactInterface::Plugin *>(left.internalPointer());
-        KontactInterface::Plugin *rightPlugin
+        auto *rightPlugin
             = static_cast<KontactInterface::Plugin *>(right.internalPointer());
 
         if (leftPlugin->weight() == rightPlugin->weight()) {
@@ -274,7 +261,7 @@ Navigator::Navigator(SidePaneBase *parent)
     mShowIcons = Prefs::self()->sidePaneShowIcons();
     mShowText = Prefs::self()->sidePaneShowText();
 
-    QActionGroup *viewMode = new QActionGroup(this);
+    auto *viewMode = new QActionGroup(this);
     connect(viewMode, &QActionGroup::triggered, this, &Navigator::slotActionTriggered);
 
     mShowIconsAction = new QAction(i18nc("@action:inmenu", "Show Icons Only"), this);
@@ -310,7 +297,7 @@ Navigator::Navigator(SidePaneBase *parent)
         i18nc("@info:whatsthis",
               "Choose this option if you want the sidebar items to have icons and text."));
 
-    QActionGroup *iconSize = new QActionGroup(this);
+    auto *iconSize = new QActionGroup(this);
     connect(iconSize, &QActionGroup::triggered, this, &Navigator::slotActionTriggered);
 
     mBigIconsAction = new QAction(i18nc("@action:inmenu", "Big Icons"), this);
@@ -355,9 +342,9 @@ Navigator::Navigator(SidePaneBase *parent)
               "Choose this option if you want to hide the icon sidebar. Press F9 to unhide."));
     connect(mHideSideBarAction, &QAction::triggered, this, &Navigator::slotHideSideBarTriggered);
 
-    QAction *sep = new QAction(this);
+    auto *sep = new QAction(this);
     sep->setSeparator(true);
-    QAction *sep2 = new QAction(this);
+    auto *sep2 = new QAction(this);
     sep2->setSeparator(true);
 
     QList<QAction *> actionList;
@@ -371,7 +358,7 @@ Navigator::Navigator(SidePaneBase *parent)
     setViewMode(ListMode);
     setItemDelegate(new Delegate(this));
     mModel = new Model(this);
-    SortFilterProxyModel *sortFilterProxyModel = new SortFilterProxyModel(this);
+    auto *sortFilterProxyModel = new SortFilterProxyModel(this);
     sortFilterProxyModel->setSourceModel(mModel);
     setModel(sortFilterProxyModel);
     setSelectionModel(new SelectionModel(sortFilterProxyModel, this));
@@ -469,7 +456,7 @@ void Navigator::dragMoveEvent(QDragMoveEvent *event)
     } else {
         const QModelIndex sourceIndex
             = static_cast<const QSortFilterProxyModel *>(model())->mapToSource(dropIndex);
-        KontactInterface::Plugin *plugin
+        auto *plugin
             = static_cast<KontactInterface::Plugin *>(sourceIndex.internalPointer());
         if (!plugin->canDecodeMimeData(event->mimeData())) {
             event->setAccepted(false);
@@ -493,7 +480,7 @@ void Navigator::dropEvent(QDropEvent *event)
     } else {
         const QModelIndex sourceIndex
             = static_cast<const QSortFilterProxyModel *>(model())->mapToSource(dropIndex);
-        KontactInterface::Plugin *plugin
+        auto *plugin
             = static_cast<KontactInterface::Plugin *>(sourceIndex.internalPointer());
         plugin->processDropEvent(event);
     }
@@ -579,7 +566,7 @@ IconSidePane::IconSidePane(KontactInterface::Core *core, QWidget *parent)
     mNavigator = new Navigator(this);
     layout()->addWidget(mNavigator);
     mNavigator->setFocusPolicy(Qt::NoFocus);
-    mNavigator->setMainWindow(dynamic_cast<MainWindow *>(core));
+    mNavigator->setMainWindow(qobject_cast<MainWindow *>(core));
     connect(mNavigator, &Navigator::pluginActivated, this, &IconSidePane::pluginSelected);
 }
 
