@@ -1,23 +1,11 @@
 /*
   This file is part of KDE Kontact.
 
-  Copyright (c) 2001 Matthias Hoelzer-Kluepfel <mhk@kde.org>
-  Copyright (c) 2002-2005 Daniel Molkentin <molkentin@kde.org>
-  Copyright (c) 2003-2005 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2001 Matthias Hoelzer-Kluepfel <mhk@kde.org>
+  SPDX-FileCopyrightText: 2002-2005 Daniel Molkentin <molkentin@kde.org>
+  SPDX-FileCopyrightText: 2003-2005 Cornelius Schumacher <schumacher@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef KONTACT_MAINWINDOW_H
